package meerkat.bulletinboard;

import com.google.common.util.concurrent.FutureCallback;
import meerkat.comm.CommunicationException;
import meerkat.protobuf.BulletinBoardAPI.*;

/**
 * Created by Arbel Deutsch Peled on 13-Apr-16.
 * This interface is meant to extend a BulletinBoardClient interface/class
 * It provides it with the ability to delete messages from the Server
 * This assumes the Server implements the  {@link DeletableBulletinBoardServer}
 */
public interface BulletinBoardMessageDeleter {

    /**
     * Deletes a message from a Bulletin Board Server
     * @param msgID is the ID of the message to delete
     * @param callback handles the result of the operation
     */
    public void deleteMessage(MessageID msgID, FutureCallback<Boolean> callback);

    /**
     * Deletes a message from the Bulletin Board
     * Logs this action
     * @param entryNum is the serial entry number of the message to delete
     * @param callback handles the result of the operation
     */
    public void deleteMessage(long entryNum, FutureCallback<Boolean> callback);

}
